'''
Created on 2014-11-20

@author: Administrator

TLsim_v1

This script is used for simulating patterns of single nucleotide polymorphism (SNP) data in a region 
that is linked to two biallelic sites according to selection or neutral model.

Easy to start: 
You only need to input the haplotype frequency of two locus selected
The result would be placed into output file named as simulation.out or the name which was specified
The first line of output is "//"
the second line is number of SNPs in the region
the third line is the position of SNPs in the region
the forth line is the position of selected two locus
the follow line is the sample

Options:
-n: number of samples, default is 30
-r: number of replication, default is 1
-l: length of region (bp), default is 100kb
-g: number of generations, default is 30
-t: positions of selected two locus. If it was not specified, randomly sampled from the region
-p: frequencies of haplotype from two locus that need to input, the order is p00,p01,p10,p11 seperated by ",". 0 is ancestor and 1 is derived.
-R: recombination rate between two locus, default is 0.5 meaning that the selected two-locus are not linked
-s: selected coefficient of derived allele from two locus seperated by "," meaning the selective advantage of derived allele. Default is 0 and 0 respectively corresponding to neutral model
-e: number of SNPs were simulated in the region. If it was not specified, randomly generated according to the length of region.
-o: name of output file, default is simulation.out 


''' 
from setuptools import setup, find_packages  # Always prefer setuptools over distutils
from codecs import open  # To use a consistent encoding
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='TLsim',
    version='0.2.0',

    description='simulating patterns of single nucleotide polymorphism (SNP) data in a region that is linked to two biallelic sites according to selection or neutral model',
    long_description=long_description,
    scripts = ['TLsim/bin/TLsim.py'],

    # The project's main homepage.
    url='https://github.com/pypa/TLsimproject',

    # Author details
    author='Shaojun Zhang',
    author_email='zhangshojun@ems.hrbmu.edu.cn',

    # Choose your license
    license='Python Software Foundation License',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 3 - Alpha',

        # Indicate who your project is intended for
        'Intended Audience :: Science/Research',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: Python Software Foundation License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: POSIX :: Linux',
        'Operating System :: Unix',
        'Operating System :: POSIX',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],

    keywords='two-SNPs locus evolution setuptools development',

    packages=find_packages(),

)
